==> apache-qpid-broker-j-8.0.6-src.tar.gz: apache-qpid-broker-j-8.0.6-src/broker-plugins/amqp-1-0-protocol/src/main/java/org/apache/qpid/server/protocol/v1_0/codec/RestrictedTypeValueWriter.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
package org.apache.qpid.server.protocol.v1_0.codec;

import org.apache.qpid.server.protocol.v1_0.type.RestrictedType;

public class RestrictedTypeValueWriter<V> extends DelegatingValueWriter<RestrictedType<V>>
{

    public RestrictedTypeValueWriter(final Registry registry,
                                     final RestrictedType<V> object)
    {
        super(registry, object);
    }

    @Override
    protected Object getUnderlyingValue(final RestrictedType<V> restrictedType)
    {
        return restrictedType.getValue();
    }

    private static final Factory FACTORY = new Factory()
    {

        @Override
        public ValueWriter newInstance(final Registry registry, final Object object)
        {
            return new RestrictedTypeValueWriter(registry, (RestrictedType) object);
        }
    };

    public static void register(ValueWriter.Registry registry, Class clazz)
    {
        registry.register(clazz, FACTORY);
    }}

==> apache-qpid-broker-j-10.0.1-src.tar.gz: apache-qpid-broker-j-10.0.1-src/broker-plugins/amqp-1-0-protocol/src/main/java/org/apache/qpid/server/protocol/v1_0/codec/RestrictedTypeValueWriter.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
package org.apache.qpid.server.protocol.v1_0.codec;

import org.apache.qpid.server.protocol.v1_0.type.RestrictedType;

public class RestrictedTypeValueWriter<V> extends DelegatingValueWriter<RestrictedType<V>>
{
    private static final Factory FACTORY =
            (registry, object) -> new RestrictedTypeValueWriter(registry, (RestrictedType) object);

    public RestrictedTypeValueWriter(final Registry registry,
                                     final RestrictedType<V> object)
    {
        super(registry, object);
    }

    @Override
    protected Object getUnderlyingValue(final RestrictedType<V> restrictedType)
    {
        return restrictedType.getValue();
    }

    public static void register(ValueWriter.Registry registry, Class clazz)
    {
        registry.register(clazz, FACTORY);
    }
}
